@@ -3,6 +3,7 @@ import hashlib
 import logging
 import binascii
 from Crypto.Cipher import AES
+from pyDes import des, PAD_PKCS5, ECB, CBC
 
 logger = logging.getLogger(__name__)
 
@@ -58,3 +59,27 @@ class CryptoModel:
         ' 解密函数 '
         cryptor = AES.new(self.key, self.mode, self.iv)
         return cryptor.decrypt(binascii.a2b_hex(data)).decode()
+
+
+class DESModel:
+    """
+    DES加密类
+    """
+
+    def __init__(self, key, iv=None, mode=ECB):
+        """
+        :param key: Key
+        :param iv: Initialization vector
+        :param mode: algorithm
+        """
+        if mode == ECB and iv is not None:
+            raise ValueError('MODE ECB can not IV')
+
+        self.des = des(key=key, mode=mode, IV=iv, padmode=PAD_PKCS5)
+
+    def encrypt(self, data, **kwargs):
+        res = self.des.encrypt(data, **kwargs)
+        return binascii.b2a_hex(res)
+
+    def decrypt(self, data, **kwargs):
+        return self.des.decrypt(binascii.a2b_hex(data), **kwargs)
