@@ -67,7 +67,8 @@ def is_domain(domain):
 def is_ip(target):
     """判断是否是ip"""
     try:
-        return IP(target)
+        res = IP(target)
+        return res if res and res.len() == 1 else False
     except ValueError:
         return False
 
@@ -207,6 +208,7 @@ def is_overlap_internal_cidr(target):
             res.append(INTERNAL_IP_LIST)
     return res or False
 
+
 # ########################format#########################
 
 
@@ -219,7 +221,7 @@ def format_target(target_str: str):
             assets.append(t)
         elif is_ipv4_cidr(t):
             ip, mask = t.split('/')
-            t = str(IP(ip).make_net(mask))
+            t = [str(x) for x in IP(ip).make_net(mask)]
             assets.extend(t)
         elif len(t.split('.')) == 4:
             assets.extend(split_star_and_sections(t))
@@ -228,5 +230,5 @@ def format_target(target_str: str):
         elif is_domain(t):
             assets.append(t)
         else:
-            pass
+            raise ValueError
     return ','.join(assets)
